#define CATCH_CONFIG_RUNNER
#include <catch2/catch.hpp>

#include <Kokkos_Core.hpp>

#include <mesh/DiamondDualConnectivityManager.hpp>
#include <mesh/DiamondDualMeshManager.hpp>
#include <mesh/MeshDataManager.hpp>
#include <mesh/SynchronizerManager.hpp>
#include <utils/Messenger.hpp>

#include <test_MeshDataBase.hpp>

int
main(int argc, char* argv[])
{
  parallel::Messenger::create(argc, argv);
  Kokkos::initialize({4, -1, -1, true});

  Catch::Session session;
  int result = session.applyCommandLine(argc, argv);

  if (result == 0) {
    // Disable outputs from tested classes to the standard output
    std::cout.setstate(std::ios::badbit);

    SynchronizerManager::create();
    MeshDataManager::create();
    DiamondDualConnectivityManager::create();
    DiamondDualMeshManager::create();

    test_MeshDataBase::create();

    result = session.run();

    test_MeshDataBase::destroy();

    DiamondDualMeshManager::destroy();
    DiamondDualConnectivityManager::destroy();
    MeshDataManager::destroy();
    SynchronizerManager::destroy();
  }

  Kokkos::finalize();
  parallel::Messenger::destroy();
  std::cout << "finalizing\n";
  return result;
}
